[Libreoffice-commits] core.git: sw/source

Miklos Vajna vmiklos at suse.cz
Wed Mar 20 05:23:45 PDT 2013


 sw/source/core/doc/docfld.cxx |   14 ++++++++++----
 1 file changed, 10 insertions(+), 4 deletions(-)

New commits:
commit 62344016de056965a58ea2016d912a68eac0d6b0
Author: Miklos Vajna <vmiklos at suse.cz>
Date:   Wed Mar 20 13:19:32 2013 +0100

    fdo#55814 SwDoc::UpdateExpFlds: hiding the last section may be safe
    
    In case we know there is a non-section paragraph at the end of the
    document.  Intentionally not adding a unit test as David Ostrovsky is
    working on one already.
    
    Change-Id: Ia6026846981b5af014246a8a604c5f762d34c891

diff --git a/sw/source/core/doc/docfld.cxx b/sw/source/core/doc/docfld.cxx
index 8c01695..8474c96 100644
--- a/sw/source/core/doc/docfld.cxx
+++ b/sw/source/core/doc/docfld.cxx
@@ -1304,10 +1304,16 @@ void SwDoc::UpdateExpFlds( SwTxtFld* pUpdtFld, bool bUpdRefFlds )
                     // This section will be hidden, but it wasn't before
                     if (nShownSections == 1)
                     {
-                        // This would be the last section, so set its condition to false, and avoid hiding it.
-                        OUString aCond("0");
-                        pSect->SetCondition(aCond);
-                        bHide = false;
+                        // Is the last node part of a section?
+                        SwPaM aPam(GetNodes());
+                        aPam.Move(fnMoveForward, fnGoDoc);
+                        if (aPam.Start()->nNode.GetNode().StartOfSectionNode()->IsSectionNode())
+                        {
+                            // This would be the last section, so set its condition to false, and avoid hiding it.
+                            OUString aCond("0");
+                            pSect->SetCondition(aCond);
+                            bHide = false;
+                        }
                     }
                     nShownSections--;
                 }


More information about the Libreoffice-commits mailing list